@@ -6,7 +6,7 @@ C R port: copyright 1998-2000 by Roger S. Bivand
 
       implicit real*8 (a-h,o-z)
 
-      include 'bounds.cmn'
+      include 'bounds.h'
 
       dimension x(n),y(n),s(ns+1),Covmat(ns,ns),xp(np+1),yp(np+1)
       dimension Amat(n,ns),Bvec(ns)
